*diskmap*
=========

.. image:: https://badge.fury.io/py/diskmap.svg
    :target: https://badge.fury.io/py/diskmap

.. image:: https://img.shields.io/badge/Python-3.6%2C%203.7-yellow.svg?style=flat
    :target: https://pypi.python.org/pypi/diskmap

.. image:: https://travis-ci.org/tomasstolker/diskmap.svg?branch=master
    :target: https://travis-ci.org/tomasstolker/diskmap

.. image:: https://readthedocs.org/projects/diskmap/badge/?version=latest
    :target: http://diskmap.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/tomasstolker/diskmap/badge.svg
   :target: https://coveralls.io/github/tomasstolker/diskmap

.. image:: https://www.codefactor.io/repository/github/tomasstolker/diskmap/badge
   :target: https://www.codefactor.io/repository/github/tomasstolker/diskmap

.. image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat
    :target: https://github.com/tomasstolker/diskmap/blob/master/LICENSE

.. image:: https://img.shields.io/badge/arXiv-1609.09505-orange.svg?style=flat
    :target: https://arxiv.org/abs/1609.09505

Python tool for scattered light mapping of protoplanetary disks. The disk surface is parameterized with a power law profile or read from an input file. The projected radius and scattering angle is then calculated at each pixel. From this, a deprojected image, a stellar irradiation corrected image, and a scattering phase function can be extracted.

Documentation
-------------

Documentation can be found at `http://diskmap.readthedocs.io <http://diskmap.readthedocs.io>`_.

Attribution
-----------

Please cite `Stolker et al. (2016) <https://ui.adsabs.harvard.edu/abs/2016A%26A...596A..70S>`_ whenever results from *diskmap* are used in a publication.

Contributing
------------

Contributions are welcome, please consider forking the repository and creating a pull request. Bug reports can be provided by creating an `issue <https://github.com/tomasstolker/diskmap/issues>`_ on the Github page.

License
-------

Copyright 2020 Tomas Stolker

*diskmap* is distributed under the MIT License. See the LICENSE file for the terms and conditions.
